@@ -1,7 +1,7 @@
-// $Id: ConstituentSubtractor.cc 1352 2023-05-12 08:36:24Z peter.berta $
+// $Id: ConstituentSubtractor.cc 1373 2024-02-02 13:11:43Z peter.berta $
 //
 // ConstituentSubtractor package
-// Questions/comments: berta@ipnp.troja.mff.cuni.cz, Martin.Spousta@cern.ch, David.W.Miller@uchicago.edu, Rupert.Leitner@mff.cuni.cz
+// Questions/comments: peter.berta@cern.ch, Martin.Spousta@cern.ch, David.W.Miller@uchicago.edu, Rupert.Leitner@mff.cuni.cz
 //
 // Copyright (c) 2014-, Peter Berta, Martin Spousta, David W. Miller, Rupert Leitner
 //
@@ -34,37 +34,6 @@ LimitedWarning ConstituentSubtractor::_warning_unused_rhom;
   ///
   /// default constructor
   ConstituentSubtractor::ConstituentSubtractor(){
-    _bge_rho=0;
-    _bge_rhom=0;
-    _common_bge=false;
-    _rhom_from_bge_rhom=false;
-    _externally_supplied_rho_rhom=false;
-    _do_mass_subtraction=false;
-    _masses_to_zero=true;
-    _distance=deltaR;
-    _alpha=0;
-    _polarAngleExp=0;
-    _max_distance=-1;
-    _remove_particles_with_zero_pt_and_mass=true;
-    _remove_all_zero_pt_particles=false;
-    _use_max_distance=false;
-    _ghost_area=0.01;
-    _grid_size_phi=-1;
-    _grid_size_rap=-1;
-    _ghosts_constructed=false;
-    _ghosts_rapidity_sorted=false;
-    _n_ghosts_phi=-1;
-    _max_eta=-1;
-    _grid_size_background_estimator=0.5;
-    _rescaling=0;
-    _use_nearby_hard=false;
-    _fix_pseudorapidity=false;
-    _scale_fourmomentum=false;
-    _hard_proxies=0;
-    _ghost_selector=0;
-    _particle_selector=0;
-    _nearby_hard_radius=-1;
-    _nearby_hard_factor=-1;
   }
 
 
@@ -73,57 +42,20 @@ LimitedWarning ConstituentSubtractor::_warning_unused_rhom;
   /// rho and optionally a pointer to a background estimator for
   /// rho_m.
   ConstituentSubtractor::ConstituentSubtractor(fastjet::BackgroundEstimatorBase *bge_rho, fastjet::BackgroundEstimatorBase *bge_rhom, double alpha, double max_distance, Distance distance) :
-    _bge_rho(bge_rho), _bge_rhom(bge_rhom), _common_bge(false),  _externally_supplied_rho_rhom(false), _distance(distance), _alpha(alpha), _max_distance(max_distance){
+    _bge_rho(bge_rho), _bge_rhom(bge_rhom), _common_bge(false),  _externally_supplied_rho_rhom(false), _alpha(alpha), _distance(distance), _max_distance(max_distance){
     if (_max_distance>0) _use_max_distance=true;
     else _use_max_distance=false;
-    _polarAngleExp=0;
-    _ghost_area=0.01;
-    _remove_particles_with_zero_pt_and_mass=true;
-    _remove_all_zero_pt_particles=false;
-    _max_eta=-1;
-    _ghosts_constructed=false;
-    _ghosts_rapidity_sorted=false;
-    _n_ghosts_phi=-1;
-    _do_mass_subtraction=false;
-    _masses_to_zero=true;
-    _use_nearby_hard=false;
-    _fix_pseudorapidity=false;
-    _scale_fourmomentum=false;
-    _hard_proxies=0;
-    _ghost_selector=0;
-    _particle_selector=0;
-    _nearby_hard_radius=-1;
-    _nearby_hard_factor=-1;
   }
 
 
   ///
   /// Constructor that takes an externally supplied value for rho and, optionally, for rho_m.
-  ConstituentSubtractor::ConstituentSubtractor(double rho, double rhom, double alpha, double max_distance, Distance distance) :      
-    _bge_rho(0), _bge_rhom(0), _common_bge(false), _rhom_from_bge_rhom(false), _rho(rho), _rhom(rhom), _externally_supplied_rho_rhom(true), _distance(distance), _alpha(alpha), _max_distance(max_distance) {
+  ConstituentSubtractor::ConstituentSubtractor(double rho, double rhom, double alpha, double max_distance, Distance distance):
+    _bge_rho(0), _bge_rhom(0), _common_bge(false), _rhom_from_bge_rhom(false), _rho(rho), _rhom(rhom), _externally_supplied_rho_rhom(true), _alpha(alpha), _distance(distance), _max_distance(max_distance) {
     if (_max_distance>0) _use_max_distance=true;
     else _use_max_distance=false;
     assert(_rho  >= 0);
     assert(_rhom >= 0);
-
-    _do_mass_subtraction=false;
-    _masses_to_zero=true;
-    _polarAngleExp=0;
-    _ghost_area=0.01;
-    _remove_particles_with_zero_pt_and_mass=true;
-    _remove_all_zero_pt_particles=false;
-    _ghosts_constructed=false;
-    _ghosts_rapidity_sorted=false;
-    _n_ghosts_phi=-1;
-    _max_eta=-1;
-    _use_nearby_hard=false;
-    _fix_pseudorapidity=false;
-    _scale_fourmomentum=false;
-    _hard_proxies=0;
-    _ghost_selector=0;
-    _particle_selector=0;
-    _nearby_hard_radius=-1;
-    _nearby_hard_factor=-1;
   }
 
 
