@@ -7,7 +7,7 @@
 // Copyright (c) 2013-2016
 // Andrew Larkoski, Lina Necib, Gavin Salam, and Jesse Thaler
 //
-// $Id: example.cc 1097 2018-01-05 00:04:20Z linoush $
+// $Id: example.cc 1393 2024-02-23 13:38:42Z jthaler $
 //----------------------------------------------------------------------
 // This file is part of FastJet contrib.
 //
@@ -152,7 +152,7 @@ void analyze(const vector<PseudoJet> & input_particles) {
                     EnergyCorrelator ECF4(4,beta,measurelist[M]);
                     EnergyCorrelator ECF5(5,beta,measurelist[M]);
 
-                    printf("%7.3f %14.2f %14.2f %14.2f %14.2f %15.2f \n",beta,ECF1(myJet),ECF2(myJet),ECF3(myJet),ECF4(myJet),ECF5(myJet));
+                    printf("%7.3f %14.2f %14.2f %14.6g %14.6g %15.6g \n",beta,ECF1(myJet),ECF2(myJet),ECF3(myJet),ECF4(myJet),ECF5(myJet));
                 }
                 cout << "-------------------------------------------------------------------------------------" << endl << endl;
 
@@ -170,7 +170,7 @@ void analyze(const vector<PseudoJet> & input_particles) {
                     EnergyCorrelatorRatio r3(3,beta,measurelist[M]);
                     EnergyCorrelatorRatio r4(4,beta,measurelist[M]);
 
-                    printf("%7.3f %14.4f %14.4f %14.4f %14.4f %15.4f \n",beta,r0(myJet),r1(myJet),r2(myJet),r3(myJet),r4(myJet));
+                    printf("%7.3f %14.4f %14.4f %14.6g %14.6g %15.6g \n",beta,r0(myJet),r1(myJet),r2(myJet),r3(myJet),r4(myJet));
                 }
                 cout << "-------------------------------------------------------------------------------------" << endl << endl;
 
@@ -248,7 +248,7 @@ void analyze(const vector<PseudoJet> & input_particles) {
 
                         EnergyCorrelatorGeneralizedD2 d2(alpha, beta, measurelist[M]);
 
-                        printf("%18.4f ", d2(myJet));
+                        printf("%18.6g ", d2(myJet));
                     }
                     printf("\n");
                 }
