@@ -11,7 +11,7 @@
 /// \endverbatim
 
 //----------------------------------------------------------------------
-// $Id: example_dpsi_slice.cc 1361 2024-01-08 18:48:40Z salam $
+// $Id: example_dpsi_slice.cc 1465 2024-12-11 14:53:28Z gsoyez $
 //
 // Copyright (c) 2018-, Frederic A. Dreyer, Keith Hamilton, Alexander Karlberg,
 // Gavin P. Salam, Ludovic Scyboz, Gregory Soyez, Rob Verheyen
@@ -40,7 +40,8 @@
 #include "fastjet/PseudoJet.hh"
 #include "fastjet/EECambridgePlugin.hh"
 #include <string>
-#include "RecursiveLundEEGenerator.hh" // In external code, this should be fastjet/contrib/RecursiveLundEEGenerator.hh
+#include "fastjet/contrib/RecursiveLundEEGenerator.hh"
+
 using namespace std;
 using namespace fastjet;
 
