@@ -7,7 +7,7 @@
 //  Run this example with:
 //     ./example_basic_usage < ../data/single-event.dat
 //
-//  $Id: example_basic_usage.cc 841 2015-08-19 17:33:59Z jthaler $
+//  $Id: example_basic_usage.cc 1384 2024-02-22 21:04:21Z jthaler $
 //----------------------------------------------------------------------
 // This file is part of FastJet contrib.
 //
@@ -133,19 +133,19 @@ void analyze(const vector<PseudoJet> & input_particles) {
       //  then you can use the simple function Nsubjettiness.
       //
       //  Recommended usage for Nsubjettiness:
-      //  AxesMode:  KT_Axes(), WTA_KT_Axes(), OnePass_KT_Axes(), or OnePass_WTA_KT_Axes()
+      //  AxesMode:  HalfKT_Axes(), WTA_KT_Axes()
       //  MeasureMode:  Unnormalized_Measure(beta)
-      //  beta with KT_Axes: 2.0
+      //  beta with HalfKT_Axes: 2.0
       //  beta with WTA_KT_Axes: anything greater than 0.0 (particularly good for 1.0)
-      //  beta with OnePass_KT_Axes or OnePass_WTA_KT_Axes:  between 1.0 and 3.0
       //
+      //  N.B. Because of instabilities with numerical minimization, OnePass axes are no longer recommended as of version 2.3.0
       ///////
       
       
       cout << "-------------------------------------------------------------------------------------" << endl;
       cout << "N-subjettiness with Unnormalized Measure (in GeV)" << endl;
-      cout << "beta = 1.0:  One-pass Winner-Take-All kT Axes" << endl;
-      cout << "beta = 2.0:  One-pass E-Scheme kT Axes" << endl;
+      cout << "beta = 1.0:  Winner-Take-All kT Axes" << endl;
+      cout << "beta = 2.0:  E-Scheme Half-kT Axes" << endl;
       cout << "-------------------------------------------------------------------------------------" << endl;
       
       
@@ -162,13 +162,13 @@ void analyze(const vector<PseudoJet> & input_particles) {
          << endl;
       
       
-      // Define Nsubjettiness functions for beta = 1.0 using one-pass WTA KT axes
+      // Define Nsubjettiness functions for beta = 1.0 using WTA KT axes
       double beta = 1.0;
-      Nsubjettiness         nSub1_beta1(1,   OnePass_WTA_KT_Axes(), UnnormalizedMeasure(beta));
-      Nsubjettiness         nSub2_beta1(2,   OnePass_WTA_KT_Axes(), UnnormalizedMeasure(beta));
-      Nsubjettiness         nSub3_beta1(3,   OnePass_WTA_KT_Axes(), UnnormalizedMeasure(beta));
-      NsubjettinessRatio   nSub21_beta1(2,1, OnePass_WTA_KT_Axes(), UnnormalizedMeasure(beta));
-      NsubjettinessRatio   nSub32_beta1(3,2, OnePass_WTA_KT_Axes(), UnnormalizedMeasure(beta));
+      Nsubjettiness         nSub1_beta1(1,   WTA_KT_Axes(), UnnormalizedMeasure(beta));
+      Nsubjettiness         nSub2_beta1(2,   WTA_KT_Axes(), UnnormalizedMeasure(beta));
+      Nsubjettiness         nSub3_beta1(3,   WTA_KT_Axes(), UnnormalizedMeasure(beta));
+      NsubjettinessRatio   nSub21_beta1(2,1, WTA_KT_Axes(), UnnormalizedMeasure(beta));
+      NsubjettinessRatio   nSub32_beta1(3,2, WTA_KT_Axes(), UnnormalizedMeasure(beta));
       
       // calculate Nsubjettiness values (beta = 1.0)
       double  tau1_beta1 =  nSub1_beta1(this_jet);
@@ -188,13 +188,13 @@ void analyze(const vector<PseudoJet> & input_particles) {
       
       // Repeat the above for beta = 2.0
       
-      // Define Nsubjettiness functions for beta = 2.0, using one-pass ordinary KT axes
+      // Define Nsubjettiness functions for beta = 2.0, using Half-KT axes
       beta = 2.0;
-      Nsubjettiness         nSub1_beta2(1,   OnePass_KT_Axes(), UnnormalizedMeasure(beta));
-      Nsubjettiness         nSub2_beta2(2,   OnePass_KT_Axes(), UnnormalizedMeasure(beta));
-      Nsubjettiness         nSub3_beta2(3,   OnePass_KT_Axes(), UnnormalizedMeasure(beta));
-      NsubjettinessRatio   nSub21_beta2(2,1, OnePass_KT_Axes(), UnnormalizedMeasure(beta));
-      NsubjettinessRatio   nSub32_beta2(3,2, OnePass_KT_Axes(), UnnormalizedMeasure(beta));
+      Nsubjettiness         nSub1_beta2(1,   HalfKT_Axes(), UnnormalizedMeasure(beta));
+      Nsubjettiness         nSub2_beta2(2,   HalfKT_Axes(), UnnormalizedMeasure(beta));
+      Nsubjettiness         nSub3_beta2(3,   HalfKT_Axes(), UnnormalizedMeasure(beta));
+      NsubjettinessRatio   nSub21_beta2(2,1, HalfKT_Axes(), UnnormalizedMeasure(beta));
+      NsubjettinessRatio   nSub32_beta2(3,2, HalfKT_Axes(), UnnormalizedMeasure(beta));
       
       // calculate Nsubjettiness values (beta = 2.0)
       double  tau1_beta2 =  nSub1_beta2(this_jet);
@@ -441,7 +441,6 @@ void PrintJets(const vector <PseudoJet>& jets, const TauComponents & components,
    if (useArea) cout << setw(10) << "area";
    cout << endl;
    
-   
    // print out individual jet information
    for (unsigned i = 0; i < jets.size(); i++) {
       cout << commentStr << setw(5) << i+1  << "   "
@@ -626,4 +625,4 @@ void PrintXConeAxes(const vector <PseudoJet>& jets, bool commentOut) {
       cout << endl;
    }
    
-}
\ No newline at end of file
+}
