@@ -1,4 +1,4 @@
-// $Id: ModifiedMassDropTagger.cc 683 2014-06-13 14:38:38Z gsoyez $
+// $Id: ModifiedMassDropTagger.cc 1458 2024-12-11 08:25:19Z salam $
 //
 // Copyright (c) 2014-, Gavin P. Salam
 //
@@ -19,7 +19,7 @@
 // along with this code. If not, see <http://www.gnu.org/licenses/>.
 //----------------------------------------------------------------------
 
-#include "ModifiedMassDropTagger.hh"
+#include "fastjet/contrib/ModifiedMassDropTagger.hh"
 #include "fastjet/JetDefinition.hh"
 #include "fastjet/ClusterSequenceAreaBase.hh"
 #include <algorithm> 
